.. IMAXT Pipeline documentation master file, created by
   sphinx-quickstart on Sat Oct 27 05:47:17 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

IMAXT IMAGE Utils
=================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   install
   ometiff
   imaxt_image
   contributing
   authors
   history
